@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,6 +19,9 @@ class KToggleAction;
 namespace PimCommon
 {
 class KActionMenuChangeCase;
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+class VerifyNewVersionWidget;
+#endif
 }
 class LIBSIEVEEDITOR_EXPORT SieveEditorMainWindow : public KXmlGuiWindow
 {
@@ -30,6 +33,8 @@ public:
     [[nodiscard]] QString currentHelpTitle() const;
     [[nodiscard]] QUrl currentHelpUrl() const;
 
+    void slotActivateRequested(const QStringList &arguments, const QString &workingDirectory);
+
 protected:
     void closeEvent(QCloseEvent *e) override;
 
@@ -98,5 +103,8 @@ private:
     KToggleFullScreenAction *mShowFullScreenAction = nullptr;
     KHamburgerMenu *mHamburgerMenu = nullptr;
     KToggleAction *mShowMenuBarAction = nullptr;
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+    PimCommon::VerifyNewVersionWidget *const mVerifyNewVersionWidget;
+#endif
     bool mNetworkIsDown = false;
 };
